import { EntityRepository, Repository } from "typeorm";
import { UpdateLandingPageUiDto } from "./dto/update-landing-page-ui.dto";
import { LandingPageUI } from "./entities/landing-page-ui.entity";

@EntityRepository(LandingPageUI)
export class LandingPageUiRepository extends Repository<LandingPageUI> {

    async createEntity(dto: UpdateLandingPageUiDto): Promise<LandingPageUI | Error> {
        try {
            const entity = this.create({
                backgroundColor: dto.backgroundColor,
                pageTitleFontColor: dto.pageTitleFontColor,
                sectionOneTitleFontColor: dto.sectionOneTitleFontColor,
                sectionTwoTitleFontColor: dto.sectionTwoTitleFontColor
            });
            await this.save(entity);
            return entity;
        } catch (e) {
            return e;
        }
    }

    async updateEntity(dto: UpdateLandingPageUiDto, id: string): Promise<LandingPageUI | Error> {
        try {
            await this.update(id, {
                backgroundColor: dto.backgroundColor,
                pageTitleFontColor: dto.pageTitleFontColor,
                sectionOneTitleFontColor: dto.sectionOneTitleFontColor,
                sectionTwoTitleFontColor: dto.sectionTwoTitleFontColor
            });
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async findAll(): Promise<LandingPageUI[] | Error> {
        try {
            return await this.find({
                where: {
                    isDeleted: false
                }
            });
        } catch (e) {
            return e;
        }
    }
}