import { EntityRepository, getConnection, Repository } from "typeorm";
import { CreateHomePageSectionOneDto } from "./dto/create-home-page-section-one.dto";
import { UpdateHomePageSectionOneDto } from "./dto/update-home-page-section-one.dto";
import { HomePageSectionOne } from "./entities/home-page-section-one.entity";

@EntityRepository(HomePageSectionOne)
export class HomePageSectionOneRepository extends Repository<HomePageSectionOne> {
    async createEntity(dto: CreateHomePageSectionOneDto): Promise<HomePageSectionOne | Error> {
        try {
            const {
                title,
                description,
                buttonText,
                buttonLink,
                image
            } = dto;
            const entity = this.create({
                title,
                description,
                buttonText,
                buttonLink,
                image
            });
            await this.save(entity);
            return entity;
        } catch (e) {
            return e;
        }
    }

    async findOneEntity(id: string): Promise<HomePageSectionOne | Error> {
        try {
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async updateEntity(id: string, dto: UpdateHomePageSectionOneDto): Promise<HomePageSectionOne | Error> {
        try {
            await this.update(id, {
                title: dto.title,
                description: dto.description,
                buttonText: dto.buttonText,
                buttonLink: dto.buttonLink,
                image: dto.image
            });
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async findByFilterQuery(query: any): Promise<HomePageSectionOne[] | Error> {
        try {
            return await this.find({
                where: { ...query, isDeleted: false }
            });
        } catch (e) {
            return e;
        }
    }

    async deleteEntity(id: string): Promise<boolean | Error> {
        try {
            const updateResult = await getConnection()
              .createQueryBuilder()
              .update(HomePageSectionOne)
              .set({ isDeleted: true })
              .where("id = :id", { id: id })
              .execute();
            if (updateResult.affected > 0) {
                return true;
            }
            return false;
        } catch (e) {
            return e;
        }
    }
}