import { EntityRepository, getConnection, Repository } from "typeorm";
import { CreateProductServiceDto } from "./dto/create-product-service.dto";
import { UpdateProductServiceDto } from "./dto/update-product-service.dto";
import { ProductService } from "./entities/product-service.entity";

@EntityRepository(ProductService)
export class ProductServiceRepository extends Repository<ProductService> {
    async createEntity(dto: CreateProductServiceDto): Promise<any | Error> {
        try {
            const entity = this.create({
                retailerId: dto.retailerId,
                retailerName: dto.retailerName,
                productId: dto.productId,
                productName: dto.productName,
                productSlug: dto.productSlug,
                image: dto.image,
                brandName: dto.brandName,
                category: dto.category,
                variants: dto.variants
            });
            await this.save(entity);
            return entity;
        } catch (e) {
            return e;
        }
    }

    async findAll(): Promise<any | Error> {
        try {
            return await this.find({
                order: {
                    createdAt: -1
                },
                where: {
                    isDeleted: false
                }
            });
        } catch (e) {
            return e;
        }
    }

    async findOneEntity(slug: string): Promise<any | Error> {
        try {
            return await this.findOne({
                where: {
                    productSlug: slug,
                    isDeleted: false
                }
            });
        } catch (e) {
            return e;
        }
    }

    async deleteEntity(id: string): Promise<boolean | Error> {
        try {
            const updateResult = await getConnection()
              .createQueryBuilder()
              .update(ProductService)
              .set({ isDeleted: true })
              .where("id = :id", { id: id })
              .execute();
            return updateResult.affected > 0;
        } catch (e) {
            return e;
        }
    }

    async updateProductCategory(
      id: string,
      dto: UpdateProductServiceDto
    ): Promise<ProductService | Error> {
        try {
            await this.update(id, {
                retailerId: dto.retailerId,
                retailerName: dto.retailerName,
                productId: dto.productId,
                productName: dto.productName,
                productSlug: dto.productSlug,
                image: dto.image,
                brandName: dto.brandName,
                category: dto.category,
                variants: dto.variants
            });
            return await this.findOne({ where: { id: id } });
        } catch (e) {
            return e;
        }
    }
}
